==> jqwik-engine-1.6.5.jar: module-info.java <==
/* synthetic */ module net.jqwik.engine {
    requires java.logging;
    requires net.jqwik.api;
    requires org.junit.platform.engine;

    opens net.jqwik.engine.properties.configurators to org.junit.platform.commons;

    provides ReflectionSupportFacade with ReflectionSupportFacadeImpl;
    provides ShrinkingSupportFacade with ShrinkingSupportFacadeImpl;
    provides TestingSupportFacade with TestingSupportFacadeImpl;
    provides Arbitraries.ArbitrariesFacade with ArbitrariesFacadeImpl;
    provides Arbitrary.ArbitraryFacade with ArbitraryFacadeImpl;
    provides Combinators.CombinatorsFacade with CombinatorsFacadeImpl;
    provides EdgeCases.EdgeCasesFacade with EdgeCasesFacadeImpl;
    provides ExhaustiveGenerator.ExhaustiveGeneratorFacade with ExhaustiveGeneratorFacadeImpl;
    provides Functions.FunctionsFacade with FunctionsFacadeImpl;
    provides JavaBeanReportingFormat.JavaBeanReportingFormatFacade with JavaBeanReportingFormatFacadeImpl;
    provides RandomDistribution.RandomDistributionFacade with RandomDistributionFacadeImpl;
    provides RandomGenerator.RandomGeneratorFacade with RandomGeneratorFacadeImpl;
    provides Shrinkable.ShrinkableFacade with ShrinkableFacadeImpl;
    provides DomainContext.DomainContextFacade with DomainContextFacadeImpl;
    provides Store.StoreFacade with StoreFacadeImpl;
    provides TypeUsage.TypeUsageFacade with TypeUsageFacadeImpl;
    provides JqwikSession.JqwikSessionFacade with JqwikSessionFacadeImpl;
    provides Statistics.StatisticsFacade with StatisticsFacadeImpl;
    provides ArbitraryProvider with BigDecimalArbitraryProvider, BigIntegerArbitraryProvider, BooleanArbitraryProvider, ByteArbitraryProvider, CharacterArbitraryProvider, DoubleArbitraryProvider, FloatArbitraryProvider, IntegerArbitraryProvider, LongArbitraryProvider, ObjectArbitraryProvider, RandomArbitraryProvider, ShortArbitraryProvider, StringArbitraryProvider;
    provides LifecycleHook with DisabledHook, ResolveReporterHook, AutoCloseableHook, ContainerLifecycleMethodsHook, PropertyLifecycleMethodsHook, TryLifecycleMethodsHook, StatisticsHook;
    provides ArbitraryConfigurator with BigDecimalRangeConfigurator, BigIntegerRangeConfigurator, ByteRangeConfigurator, CharsConfigurator, DoubleRangeConfigurator, FloatRangeConfigurator, IntRangeConfigurator, LongRangeConfigurator, NegativeConfigurator, NotBlankConfigurator, PositiveConfigurator, ScaleConfigurator, ShortRangeConfigurator, StringLengthConfigurator, WhitespaceConfigurator;
    provides SampleReportingFormat with ArrayReportingFormat, OptionalReportingFormat, StreamReportingFormat, ActionSequenceReportingFormat;
    provides TestEngine with JqwikTestEngine;

}

==> jqwik-engine-1.7.0.jar: module-info.java <==
/* synthetic */ module net.jqwik.engine {
    requires java.logging;
    requires net.jqwik.api;
    requires org.junit.platform.engine;

    opens net.jqwik.engine.properties.configurators to org.junit.platform.commons;

    provides ReflectionSupportFacade with ReflectionSupportFacadeImpl;
    provides ShrinkingSupportFacade with ShrinkingSupportFacadeImpl;
    provides TestingSupportFacade with TestingSupportFacadeImpl;
    provides Arbitraries.ArbitrariesFacade with ArbitrariesFacadeImpl;
    provides Arbitrary.ArbitraryFacade with ArbitraryFacadeImpl;
    provides Combinators.CombinatorsFacade with CombinatorsFacadeImpl;
    provides EdgeCases.EdgeCasesFacade with EdgeCasesFacadeImpl;
    provides ExhaustiveGenerator.ExhaustiveGeneratorFacade with ExhaustiveGeneratorFacadeImpl;
    provides Functions.FunctionsFacade with FunctionsFacadeImpl;
    provides JavaBeanReportingFormat.JavaBeanReportingFormatFacade with JavaBeanReportingFormatFacadeImpl;
    provides RandomDistribution.RandomDistributionFacade with RandomDistributionFacadeImpl;
    provides RandomGenerator.RandomGeneratorFacade with RandomGeneratorFacadeImpl;
    provides Shrinkable.ShrinkableFacade with ShrinkableFacadeImpl;
    provides DomainContext.DomainContextFacade with DomainContextFacadeImpl;
    provides Store.StoreFacade with StoreFacadeImpl;
    provides TypeUsage.TypeUsageFacade with TypeUsageFacadeImpl;
    provides JqwikSession.JqwikSessionFacade with JqwikSessionFacadeImpl;
    provides Statistics.StatisticsFacade with StatisticsFacadeImpl;
    provides Chain.ChainFacade with ChainFacadeImpl;
    provides ActionChain.ActionChainFacade with ActionChainFacadeImple;
    provides ArbitraryProvider with BigDecimalArbitraryProvider, BigIntegerArbitraryProvider, BooleanArbitraryProvider, ByteArbitraryProvider, CharacterArbitraryProvider, DoubleArbitraryProvider, FloatArbitraryProvider, IntegerArbitraryProvider, LongArbitraryProvider, ObjectArbitraryProvider, RandomArbitraryProvider, ShortArbitraryProvider, StringArbitraryProvider;
    provides LifecycleHook with DisabledHook, ResolveReporterHook, AutoCloseableHook, ContainerLifecycleMethodsHook, PropertyLifecycleMethodsHook, TryLifecycleMethodsHook, StatisticsHook;
    provides ArbitraryConfigurator with BigDecimalRangeConfigurator, BigIntegerRangeConfigurator, ByteRangeConfigurator, CharsConfigurator, DoubleRangeConfigurator, FloatRangeConfigurator, IntRangeConfigurator, LongRangeConfigurator, NegativeConfigurator, NotBlankConfigurator, PositiveConfigurator, ScaleConfigurator, ShortRangeConfigurator, StringLengthConfigurator, WhitespaceConfigurator;
    provides SampleReportingFormat with ArrayReportingFormat, OptionalReportingFormat, StreamReportingFormat, ActionSequenceReportingFormat;
    provides TestEngine with JqwikTestEngine;

}
